==> rc-ui-lib-0.1.35.tgz: package/es/hooks/use-event-listener.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";

/* eslint-disable react-hooks/rules-of-hooks */

/* eslint-disable @typescript-eslint/no-unused-vars */
import { useEffect } from 'react';
import { inBrowser } from '../utils'; // https://developer.mozilla.org/zh-CN/docs/Web/API/EventTarget/addEventListener#使用_passive_改善的滚屏性能

var supportsPassive = false;

if (inBrowser) {
  try {
    var opts = {};
    Object.defineProperty(opts, 'passive', {
      get: function get() {
        supportsPassive = true;
      }
    });
    window.addEventListener('test-passive', null, opts); // eslint-disable-next-line no-empty
  } catch (e) {}
}

function useEventListener(type, listener) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  if (!inBrowser) {
    return;
  }

  var _options$target = options.target,
      target = _options$target === void 0 ? window : _options$target,
      _options$passive = options.passive,
      passive = _options$passive === void 0 ? false : _options$passive,
      _options$capture = options.capture,
      capture = _options$capture === void 0 ? false : _options$capture,
      _options$depends = options.depends,
      depends = _options$depends === void 0 ? [] : _options$depends;
  var attached;

  var add = function add() {
    var element = target;

    if (element && !attached) {
      element.addEventListener(type, listener, supportsPassive ? {
        capture: capture,
        passive: passive
      } : capture);
      attached = true;
    }
  };

  var remove = function remove() {
    var element = target;

    if (element && attached) {
      element.removeEventListener(type, listener, capture);
      attached = false;
    }
  }; // https://stackoverflow.com/questions/55265255/react-usestate-hook-event-handler-using-initial-state


  useEffect(function () {
    add();
    return function () {
      return remove();
    };
  }, [target].concat(_toConsumableArray(depends)));
}

export default useEventListener;

==> rc-ui-lib-1.3.5.tgz: package/es/hooks/use-event-listener.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
/* eslint-disable react-hooks/rules-of-hooks */
/* eslint-disable @typescript-eslint/no-unused-vars */
import { useEffect } from 'react';
import { inBrowser } from '../utils';

// https://developer.mozilla.org/zh-CN/docs/Web/API/EventTarget/addEventListener#使用_passive_改善的滚屏性能
var supportsPassive = false;
if (inBrowser) {
  try {
    var opts = {};
    Object.defineProperty(opts, 'passive', {
      get: function get() {
        supportsPassive = true;
      }
    });
    window.addEventListener('test-passive', null, opts);
    // eslint-disable-next-line no-empty
  } catch (e) {}
}
function useEventListener(type, listener) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  if (!inBrowser) {
    return;
  }
  var _options$target = options.target,
    target = _options$target === void 0 ? window : _options$target,
    _options$passive = options.passive,
    passive = _options$passive === void 0 ? false : _options$passive,
    _options$capture = options.capture,
    capture = _options$capture === void 0 ? false : _options$capture,
    _options$depends = options.depends,
    depends = _options$depends === void 0 ? [] : _options$depends;
  var attached;
  var add = function add() {
    var element = target;
    if (element && !attached) {
      element.addEventListener(type, listener, supportsPassive ? {
        capture: capture,
        passive: passive
      } : capture);
      attached = true;
    }
  };
  var remove = function remove() {
    var element = target;
    if (element && attached) {
      element.removeEventListener(type, listener, capture);
      attached = false;
    }
  };

  // https://stackoverflow.com/questions/55265255/react-usestate-hook-event-handler-using-initial-state
  useEffect(function () {
    add();
    return function () {
      return remove();
    };
  }, [target].concat(_toConsumableArray(depends)));
}
export default useEventListener;
